@@ -29,11 +29,21 @@ __all__ = ['celery_app']
 #     finally:
 #         return errors
 
-import os
-import sys
 
 def manage():
+    import os
+    import sys
+
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", "crm.settings")
-    os.environ.setdefault("DJANGO_CONFIGURATION", 'Production')
+
+    import os
+    from dotenv import load_dotenv
+    # explicitly providing path to '.env'
+    from pathlib import Path  # python3 only
+    env_path = Path('.') / '.crm'
+    load_dotenv(dotenv_path=env_path)
+
+    os.environ.setdefault("DJANGO_CONFIGURATION", os.getenv('KRYNEGGER_CONFIGURATION'))
+
     from django.core.management import execute_from_command_line
     execute_from_command_line(sys.argv)
\ No newline at end of file
